# calisim

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![License](https://img.shields.io/badge/License-Apache_2.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
[![CI/CD](https://github.com/PlantandFoodResearch/calisim/actions/workflows/cicd.yaml/badge.svg?branch=main)](https://github.com/PlantandFoodResearch/calisim/actions/workflows/cicd.yaml)
[![Documentation](https://github.com/PlantandFoodResearch/calisim/actions/workflows/docs.yaml/badge.svg?branch=main)](https://github.com/PlantandFoodResearch/calisim/actions/workflows/docs.yaml)
[![pages-build-deployment](https://github.com/PlantandFoodResearch/calisim/actions/workflows/pages/pages-build-deployment/badge.svg?branch=gh-pages)](https://github.com/PlantandFoodResearch/calisim/actions/workflows/pages/pages-build-deployment)

*A library of methods to calibrate simulation models.*

# Table of contents

- [calisim](#calisim)
- [Table of contents](#table-of-contents)
- [Introduction](#introduction)

# Introduction

This repository contains various methods for calibrating simulation models.
